@@ -1,7 +1,6 @@
 /***************************************************************************
                           kpopup.cpp  -  description
                           --------------------------
-    begin                : Sun Feb 20 2000
     copyright            : (C) 2000 by Torsten Henschel
     email                : henschel@fh-brandenburg.de
  ***************************************************************************/
@@ -16,6 +15,7 @@
  ***************************************************************************/
 
 #include <malloc.h>
+#include <time.h>
 #include <string.h>
 
 #include <kapp.h>
@@ -28,6 +28,8 @@
 KPopup::KPopup(int argc, char **argv, QWidget *parent=0, const char *name=0)
        : QWidget(parent, name)
 {
+ time_t atime;
+
  if(argc == 3)
    {
     Filename = (char *)malloc(((strlen(argv[1]) +1 ) * (sizeof(char))));
@@ -46,10 +48,8 @@ KPopup::KPopup(int argc, char **argv, QWidget *parent=0, const char *name=0)
     Sender[0] = 0;
    }
 
- //config = kapp -> getConfig();
-
- setMinimumSize(290, 250);
- setMaximumSize(290, 250);
+ setMinimumSize(290, 260);
+ setMaximumSize(290, 260);
     
  B_Quit = new QPushButton("Quit", this, "quit");
  B_Quit -> setGeometry(20, 10, 75, 30);
@@ -75,6 +75,29 @@ KPopup::KPopup(int argc, char **argv, QWidget *parent=0, const char *name=0)
  L_Sender -> setFrameStyle(QFrame::Panel | QFrame::Sunken);
  L_Sender -> setAlignment(AlignTop | AlignLeft);
 
+ L_Label_Time = new QLabel("Popup time:", this);
+ L_Label_Time -> setGeometry(22, 78, 98, 20);
+ L_Label_Time -> setAlignment(AlignTop | AlignLeft);
+
+ Time = (char *) malloc (20 * (sizeof(char)));
+
+ if(argc == 3)
+   {
+    atime = time(NULL);
+    strftime(Time, 20, "%G-%m-%d   %H:%M", localtime(&atime));
+   }
+  else
+   {
+    Time[0] = 0;
+   }
+
+ L_Time = new QLabel(Time, this);
+ L_Time -> setGeometry(120, 75, 150, 20);
+ L_Time -> setFrameStyle(QFrame::Panel | QFrame::Sunken);
+ L_Time -> setAlignment(AlignTop | AlignLeft);
+
+ free(Time);
+
  if(strlen(Filename) != 0)
    {
     L_PopupText = new QLabel(File_read(Filename, 41), this);
@@ -84,7 +107,7 @@ KPopup::KPopup(int argc, char **argv, QWidget *parent=0, const char *name=0)
     L_PopupText = new QLabel("", this);
    }
 
- L_PopupText -> setGeometry(20, 80, 250, 150);
+ L_PopupText -> setGeometry(20, 100, 250, 150);
  L_PopupText -> setFrameStyle(QFrame::Panel | QFrame::Sunken);
  L_PopupText -> setAlignment(AlignTop | AlignLeft);
 }
@@ -99,7 +122,6 @@ void KPopup::AnswerPopup()
      AnswerPopupView -> resize(280, 220);
      AnswerPopupView -> setCaption("Answer Popup");
      AnswerPopupView -> CB_Receiver -> insertItem(Sender, -1);
-//     AnswerPopupView -> ReadConfigHosts();
      AnswerPopupView -> ReadBrowseList();
      AnswerPopupView -> CB_Receiver -> setCurrentItem(0);
      AnswerPopupView -> exec();
@@ -112,7 +134,6 @@ void KPopup::AnswerPopup()
      NewPopupView -> resize(280, 220);
      NewPopupView -> setCaption("New Popup");
      NewPopupView -> CB_Receiver -> insertItem("NO HOST", -1);
-//     NewPopupView -> ReadConfigHosts();
      NewPopupView -> ReadBrowseList();
      NewPopupView -> CB_Receiver -> setCurrentItem(0);
      NewPopupView -> exec();
@@ -127,7 +148,6 @@ void KPopup::NewPopup()
   NewPopupView -> resize(280, 220);
   NewPopupView -> setCaption("New Popup");
   NewPopupView -> CB_Receiver -> insertItem("NO HOST", -1);
-//  NewPopupView -> ReadConfigHosts();
   NewPopupView -> ReadBrowseList();
   NewPopupView -> CB_Receiver -> setCurrentItem(0);
   NewPopupView -> exec();
