@@ -1,7 +1,6 @@
 /***************************************************************************
                           kpopup.h  -  description
                           ------------------------
-    begin                : Sun Feb 20 2000
     copyright            : (C) 2000 by Torsten Henschel
     email                : henschel@fh-brandenburg.de
  ***************************************************************************/
@@ -42,6 +41,9 @@ class KPopup : public QWidget
          QLabel *L_PopupText;
          QLabel *L_Label_Sender;
          QLabel *L_Sender;
+         QLabel *L_Label_Time;
+         QLabel *L_Time;
          char *Sender;
          char *Filename;
+         char *Time;
 };
