@@ -1,7 +1,6 @@
 /***************************************************************************
                           main.cpp  -  description
                           ------------------------
-    begin                : Sun Feb 20 2000
     copyright            : (C) 2000 by Torsten Henschel
     email                : henschel@fh-brandenburg.de
  ***************************************************************************/
@@ -29,7 +28,7 @@ int main(int argc, char **argv)
    {
     a.beep();
    }
- w.setCaption("KPopup");
+ w.setCaption("KPopup 0.3.0");
  w.show();
  return a.exec();
 }
\ No newline at end of file
