@@ -1,7 +1,6 @@
 /***************************************************************************
                           make_popup.cpp  -  description
                           ------------------------------
-    begin                : Sun Feb 20 2000
     copyright            : (C) 2000 by Torsten Henschel
     email                : henschel@fh-brandenburg.de
  ***************************************************************************/
@@ -32,36 +31,38 @@
 
 make_Popup::make_Popup(QWidget *parent, const char *name) : QDialog(parent, name, TRUE)
 {
+ hostname = (char *) malloc (30 * (sizeof(char)));
+
+ ReadHostName();
+
  B_Ok = new QPushButton("Ok", this);
- B_Ok -> setGeometry(25, 190, 60, 25);
+ B_Ok -> setGeometry(25, 165, 60, 25);
  connect(B_Ok, SIGNAL(clicked()), SLOT(SendPopup()));
 
  B_Cancel = new QPushButton("Cancel", this );
- B_Cancel -> setGeometry(195, 190, 60,25);
+ B_Cancel -> setGeometry(195, 165, 60, 25);
  connect(B_Cancel, SIGNAL(clicked()), SLOT(reject()));
 
- L_User = new QLabel("From:", this);
- L_User -> setGeometry(20, 9, 30, 20);
-
- LE_User = new QLineEdit(this, "read-write combo");
- LE_User -> setGeometry(55, 8, 205, 22);
- ReadHostName();
- LE_User -> setMaxLength(25);
-
  L_Receiver = new QLabel("To:", this);
- L_Receiver -> setGeometry(20, 34, 30, 20);
+ L_Receiver -> setGeometry(20, 9, 30, 20);
 
  CB_Receiver = new QComboBox(TRUE, this, "read-write combo");
- CB_Receiver -> setGeometry(55, 34, 205, 26);
+ CB_Receiver -> setGeometry(55, 8, 205, 22);
 
  L_Text = new QLabel("Text:", this);
- L_Text -> setGeometry(20, 61, 98, 20);
+ L_Text -> setGeometry(20, 33, 98, 20);
 
  MLE_Text = new QMultiLineEdit(this);
- MLE_Text -> setGeometry(20, 85, 240, 100);
+ MLE_Text -> setGeometry(20, 57, 240, 100);
 
- setMinimumSize(280, 220);
- setMaximumSize(280, 220);
+ setMinimumSize(280, 195);
+ setMaximumSize(280, 195);
+}
+
+
+make_Popup::~make_Popup()
+{
+ free(hostname);
 }
 
 
@@ -71,7 +72,7 @@ void make_Popup::SendPopup()
  char *befehlszeile;
  int count=0;
 
- befehlszeile = (char *)malloc(182 * (sizeof(char)));
+ befehlszeile = (char *) malloc (182 * (sizeof(char)));
  Datei = fopen("/tmp/new.kpopup", "w+");
 
  while(count < MLE_Text -> numLines())
@@ -80,10 +81,9 @@ void make_Popup::SendPopup()
    count++;
   }
  fclose(Datei);
- sprintf(befehlszeile, "cat /tmp/new.kpopup | %s/smbclient -M %s -N -U %s", SMBPATH , CB_Receiver -> currentText(), LE_User -> text());
+ sprintf(befehlszeile, "cat /tmp/new.kpopup | %s/smbclient -M %s -N -U %s", SMBPATH , CB_Receiver -> currentText(), hostname);
  if(system(befehlszeile) == 0)
    {
-//    SaveConfigHosts(CB_Receiver -> currentText());
     QMessageBox *Super;
     Super = new QMessageBox();
     Super -> information(this, "Success", "Popup sent!");
@@ -109,7 +109,7 @@ void make_Popup::ReadBrowseList()
 
  line = (char *) malloc (201 * (sizeof(char)));
  host = (char *) malloc (22 * (sizeof(char)));
- hostfile = new QFile("/tmp/hostlist.kpopup");
+ hostfile = new QFile("/tmp/kpopup.hostlist");
 
  if(hostfile -> open(IO_ReadOnly))
    {
@@ -141,70 +141,11 @@ void make_Popup::ReadBrowseList()
    }
 }
 
-/*
-void make_Popup::ReadConfigHosts()
-{
- config = kapp -> getConfig();
- config -> setGroup("HOSTS");
- fprintf(stderr, "%s\n", (const char*)config -> readEntry("RecentHost0"));
- CB_Receiver -> insertItem(config -> readEntry("RecentHost0"));
- CB_Receiver -> insertItem(config -> readEntry("RecentHost1"));
- CB_Receiver -> insertItem(config -> readEntry("RecentHost2"));
- CB_Receiver -> insertItem(config -> readEntry("RecentHost3"));
- CB_Receiver -> insertItem(config -> readEntry("RecentHost4"));
- CB_Receiver -> insertItem(config -> readEntry("RecentHost5"));
- CB_Receiver -> insertItem(config -> readEntry("RecentHost6"));
- CB_Receiver -> insertItem(config -> readEntry("RecentHost7"));
- CB_Receiver -> insertItem(config -> readEntry("RecentHost8"));
- CB_Receiver -> insertItem(config -> readEntry("RecentHost9"));
-} */
-
 
 void make_Popup::ReadHostName()
 {
- char *host;
- host = (char *) malloc (30 * (sizeof(char)));
-
- gethostname(host, 30);
- for(int i = 0; i <= 29; i++) host[i] = toupper(host[i]);
- LE_User -> setText(host);
-
- free(host);
+ gethostname(hostname, 30);
+ for(int i = 0; i <= 29; i++) hostname[i] = toupper(hostname[i]);
 }
 
 
-/*void make_Popup::SaveConfigHosts(const char *host)
-{
- int found, i;
- char zus1[20];
- char zus2[20];
-
- config = kapp -> getConfig();
- config -> setGroup("HOSTS");
-
- found = 10;
- for(i = 0; i <= 9; i++)
-  {
-   sprintf(zus1, "RecentHost%i", i);
-   if(strcmp((const char*)config -> readEntry(zus1), host) == 0)
-     {
-      found = i;
-      break;
-     }
-  }
-
- if(found == 10)
-   {
-    found = 9;
-   }
-
- for(i = found; i > 0; i--)
-   {
-    sprintf(zus1, "RecentHost%i", i);
-    sprintf(zus2, "RecentHost%i", i - 1);
-    config -> writeEntry(zus1, (const char*)config -> readEntry(zus2));
-   }
- config -> writeEntry("RecentHost0", host);
-
- config -> sync();
-} */
\ No newline at end of file
